# Disable the automatically set build flags to the environment variables such
# as CC, CFLAGS, and etc.
# See <https://src.fedoraproject.org/rpms/redhat-rpm-config/blob/rawhide/f/macros>.
%undefine _auto_set_build_flags

Name: simde
Version: v0.8.4.rc1
Release: 1.20250630154114828717.pr1299.17.ga174c3db%{?dist}
Summary: Dummy
License: MIT
URL: https://github.com/simd-everywhere/simde
# This value is magically replaced with the archive tar.gz file created by
# `git archive` in the process of the CI.
# Set the existing file `README.md` in case of creating SRPM from this RPM spec
# file on local for testing purpose.
Source0: simde-v0.8.4.rc1.tar.gz
# A path to the CI script.
Source1: ci.sh

# List up the needed RPM package names to test here.
# clang, clang++
BuildRequires: clang
BuildRequires: gcc
# g++
BuildRequires: gcc-c++
# ninja
BuildRequires: ninja-build
# pip and setuptools are needed to install and use meson PyPI package.
BuildRequires: python3-devel
BuildRequires: python3-pip
BuildRequires: python3-setuptools
# The GNU time (/bin/time) is used for testing. Use this GNU time rather than
# the embedded time function in bash.
# https://www.gnu.org/software/time/
BuildRequires: time

# RPM package description.
%description

# The bash commands to prepare are executed.
%prep
# Print the replaced value of the Source0.
echo "Source0: %{SOURCE0}"
# Create a dummy file for a valid RPM spec file.
touch dummy.txt

# The bash commands to test are executed.
%check
# Check the directory structure in the tar.gz file.
tar tzvf "%{SOURCE0}" > source_files.txt
head -2 source_files.txt
# Check if the submodule munit is included.
grep munit source_files.txt
# Extract the source archive file.
tar xzf "%{SOURCE0}"

pushd simde-*
# Set the flags used to build the actual RPM package.
# These can be used in the CI testing script.
%global toolchain clang
export CI_CLANG_RPM_CFLAGS="%{build_cflags}"
export CI_CLANG_RPM_CXXFLAGS="%{build_cxxflags}"
export CI_CLANG_RPM_LDFLAGS="%{build_ldflags}"
%global toolchain gcc
export CI_GCC_RPM_CFLAGS="%{build_cflags}"
export CI_GCC_RPM_CXXFLAGS="%{build_cxxflags}"
export CI_GCC_RPM_LDFLAGS="%{build_ldflags}"

echo "Running the CI script %{SOURCE1}."
/bin/time -f '=> [%E]' "%{SOURCE1}"
popd

# Files included in the built RPM package.
%files
%doc dummy.txt

# Changelog entries for the RPM package.
%changelog
* Mon Jun 30 2025 Packit <hello@packit.dev> - v0.8.4.rc1-1.20250630154114828717.pr1299.17.ga174c3db
- arm64 gcc FRINT: skip native call on GCC (Michael R. Crusoe)
- gh-actions: macos 16, undef _LIBCPP_ENABLE_ASSERTIONS (Michael R. Crusoe)
- build(deps): soften hendrikmuhs/ccache-action from 1.2.17 to 1.2 (Michael R. Crusoe)
- x86 sse2 for loongarch: fix GCC build failure (#1287) (jinboson)
- riscv64: Fallback to autovec without mrvv-vector-bits flag. (#1282) (Ruhung)
- arm neon riscv64: add min.h and max.h RVV implementations. (#1283) (Ruhung)
- neon riscv64: Enable RVV segment load/store only when we have `__riscv_zvlsseg` flag. (#1285) (Ruhung)
- riscv64: Enable V feature when both zve64d and zvl128b are present (#1284) (Ruhung)
- gh-actions arm: adjust to how the CPU information is reported (Michael R. Crusoe)
- x86 avx for loongarch: use vfcmp_clt to save one instruction in `_mm_cmp_{sd,ss}` and `_mm256_cmp_pd` (jinbo)
- x86 sse2,avx2 loongarch impl: let compiler to generate instructions based on imm8 (jinbo)
- emscripten64 testing: the "--experimental-wasm-memory64" flag is no longer needed (Michael R. Crusoe)
- gh-actions: remove clang 7 & 9 testing, ubuntu 20.04 is unsupported as of 2025-04-01 (Michael R. Crusoe)
- x86 misc fixes for AVX512{F,VL}_NATIVE (Michael R. Crusoe)
- build(deps): bump hendrikmuhs/ccache-action from 1.2.16 to 1.2.17 (dependabot[bot])
- gh-actions: x86 upgrade to GCC-14 (Michael R. Crusoe)
- x86 sse2,sse3, avx: silence some false-positive warnings about unitialized structs (Michael R. Crusoe)

* Fri Jun 02 2023 Dummy Dummy <dummy@dummy.com> - 1-1
- Dummy.
